==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela acorcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol del document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° cap a drecha',
	'image_tourner_gauche' => 'Rotacion 90° cap a esquerra',
	'info_document' => 'Document ',
	'info_document_indisponible' => 'Aquel document es pas disponible',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar totes los documents ',
	'info_logo_max_taille' => 'Los lògos an de far mens de @maxi@ (aqueste fichièr fa @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dins l’Internet:',
	'info_telecharger' => 'Telecargar a partir de vòstre ordenador:',

	// T
	'texte_documents_joints' => 'Podètz autorizar que s’apondan de documents (fichièrs burotics, imatges,
 multimèdia, etc.) als articles e/o a las rubricas. Aqueles fichièrs
 pòdon puèi èsser referenciats dins
 l’article, o aparéisser a despart.', # MODIF
	'texte_documents_joints_2' => 'Aquel reglatge empacha pas d’inserir d’imatges dirèctament dins los articles.', # MODIF
	'titre_documents_joints' => 'Documents jonches',
	'tout_dossier_upload' => 'Tot lo dorsièr @upload@',

	// U
	'upload_fichier_zip' => 'Fichièr ZIP',
	'upload_fichier_zip_texte' => 'Lo fichièr que prepausatz d’installar es un fichièr Zip.',
	'upload_fichier_zip_texte2' => 'Aquel fichièr pòt èsser:',
	'upload_limit' => 'Aquel fichièr es tròp gròs pel servidor; la talha maxima autorizada en <i>upload</i> es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que conten installat sul sit. Alara los fichièrs que seràn installats sul sit son:',
	'upload_zip_telquel' => 'installat tal coma es, coma archiu comprimit Zip;'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela acorcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol del document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° cap a drecha',
	'image_tourner_gauche' => 'Rotacion 90° cap a esquerra',
	'info_document' => 'Document ',
	'info_document_indisponible' => 'Aquel document es pas disponible',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar totes los documents ',
	'info_logo_max_taille' => 'Los lògos an de far mens de @maxi@ (aqueste fichièr fa @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dins l’Internet:',
	'info_telecharger' => 'Telecargar a partir de vòstre ordenador:',

	// T
	'texte_documents_joints' => 'Podètz autorizar que s’apondan de documents (fichièrs burotics, imatges,
 multimèdia, etc.) als articles e/o a las rubricas. Aqueles fichièrs
 pòdon puèi èsser referenciats dins
 l’article, o aparéisser a despart.', # MODIF
	'texte_documents_joints_2' => 'Aquel reglatge empacha pas d’inserir d’imatges dirèctament dins los articles.', # MODIF
	'titre_documents_joints' => 'Documents jonches',
	'tout_dossier_upload' => 'Tot lo dorsièr @upload@',

	// U
	'upload_fichier_zip' => 'Fichièr ZIP',
	'upload_fichier_zip_texte' => 'Lo fichièr que prepausatz d’installar es un fichièr Zip.',
	'upload_fichier_zip_texte2' => 'Aquel fichièr pòt èsser:',
	'upload_limit' => 'Aquel fichièr es tròp gròs pel servidor; la talha maxima autorizada en <i>upload</i> es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que conten installat sul sit. Alara los fichièrs que seràn installats sul sit son:',
	'upload_zip_telquel' => 'installat tal coma es, coma archiu comprimit Zip;',
];
